@@ -5,6 +5,7 @@ module for audio spectrum analysis
 
 import wave
 import numpy as np
+import pandas as pd
 
 
 class FreqAnalysis:
@@ -39,6 +40,23 @@ class FreqAnalysis:
         freq = np.arange(0, max_idx) * data_freq
         return freq, spec[:max_idx]
 
+    def freq_feature(self, buckets: list, start_offset: int, window: int, cutoff=5000) -> np.array:
+        """
+        get the aggregated frequency features from spectrum
+        :param buckets:
+        :param start_offset:
+        :param window:
+        :param cutoff:
+        :return:
+        """
+        freq, spec = self.spectrum(start_offset, window, cutoff)
+        freq_series = pd.Series(data=np.abs(spec), index=freq)
+        features = []
+        for bucket in buckets:
+            selected_freq = freq_series[bucket[0]:bucket[1]]
+            features.append(np.mean(selected_freq))
+        return np.array(features)
+
     def __str__(self):
         return f"frame_rate: {self._frame_rate}\n" \
                f"duration: {self._duration}"
